==> cppad_2015.00.00.1.orig.tar.gz: cppad-20150000.1/doc/_whats_new_14_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'appendix.xml',
'whats_new.xml',
'whats_new_14.xml'
];
var list_down3 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'library.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down2 = [
'faq.xml',
'theory.xml',
'glossary.xml',
'bib.xml',
'bugs.xml',
'wishlist.xml',
'whats_new.xml',
'deprecated.xml',
'compare_c.xml',
'license.xml'
];
var list_down1 = [
'whats_new_14.xml',
'whats_new_13.xml',
'whats_new_12.xml',
'whats_new_11.xml',
'whats_new_10.xml',
'whats_new_09.xml',
'whats_new_08.xml',
'whats_new_07.xml',
'whats_new_06.xml',
'whats_new_05.xml',
'whats_new_04.xml',
'whats_new_03.xml'
];
var list_current0 = [
'whats_new_14.xml#Introduction',
'whats_new_14.xml#12-30',
'whats_new_14.xml#12-29',
'whats_new_14.xml#12-28',
'whats_new_14.xml#12-27',
'whats_new_14.xml#12-26',
'whats_new_14.xml#12-25',
'whats_new_14.xml#12-23',
'whats_new_14.xml#12-22',
'whats_new_14.xml#12-17',
'whats_new_14.xml#12-16',
'whats_new_14.xml#12-15',
'whats_new_14.xml#11-28',
'whats_new_14.xml#11-27',
'whats_new_14.xml#09-28',
'whats_new_14.xml#09-27',
'whats_new_14.xml#09-25',
'whats_new_14.xml#09-21',
'whats_new_14.xml#05-28',
'whats_new_14.xml#05-27',
'whats_new_14.xml#05-23',
'whats_new_14.xml#05-22',
'whats_new_14.xml#05-20',
'whats_new_14.xml#05-19',
'whats_new_14.xml#05-16',
'whats_new_14.xml#05-14',
'whats_new_14.xml#03-18',
'whats_new_14.xml#03-17',
'whats_new_14.xml#03-09',
'whats_new_14.xml#03-05',
'whats_new_14.xml#03-02',
'whats_new_14.xml#03-01',
'whats_new_14.xml#02-28',
'whats_new_14.xml#02-27',
'whats_new_14.xml#02-26',
'whats_new_14.xml#02-23',
'whats_new_14.xml#02-22',
'whats_new_14.xml#02-17',
'whats_new_14.xml#02-15',
'whats_new_14.xml#01-26',
'whats_new_14.xml#01-21',
'whats_new_14.xml#01-10'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}

==> cppad_2016.00.00.1.orig.tar.gz: cppad-20160000.1/doc/_whats_new_14_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'appendix.xml',
'whats_new.xml',
'whats_new_14.xml'
];
var list_down3 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'utility.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down2 = [
'faq.xml',
'theory.xml',
'glossary.xml',
'bib.xml',
'wish_list.xml',
'whats_new.xml',
'deprecated.xml',
'compare_c.xml',
'numeric_ad.xml',
'addon.xml',
'license.xml'
];
var list_down1 = [
'whats_new_15.xml',
'whats_new_14.xml',
'whats_new_13.xml',
'whats_new_12.xml',
'whats_new_11.xml',
'whats_new_10.xml',
'whats_new_09.xml',
'whats_new_08.xml',
'whats_new_07.xml',
'whats_new_06.xml',
'whats_new_05.xml',
'whats_new_04.xml',
'whats_new_03.xml'
];
var list_current0 = [
'whats_new_14.xml#Introduction',
'whats_new_14.xml#12-30',
'whats_new_14.xml#12-29',
'whats_new_14.xml#12-28',
'whats_new_14.xml#12-27',
'whats_new_14.xml#12-26',
'whats_new_14.xml#12-25',
'whats_new_14.xml#12-23',
'whats_new_14.xml#12-22',
'whats_new_14.xml#12-17',
'whats_new_14.xml#12-16',
'whats_new_14.xml#12-15',
'whats_new_14.xml#11-28',
'whats_new_14.xml#11-27',
'whats_new_14.xml#09-28',
'whats_new_14.xml#09-27',
'whats_new_14.xml#09-25',
'whats_new_14.xml#09-21',
'whats_new_14.xml#05-28',
'whats_new_14.xml#05-27',
'whats_new_14.xml#05-23',
'whats_new_14.xml#05-22',
'whats_new_14.xml#05-20',
'whats_new_14.xml#05-19',
'whats_new_14.xml#05-16',
'whats_new_14.xml#05-14',
'whats_new_14.xml#03-18',
'whats_new_14.xml#03-17',
'whats_new_14.xml#03-09',
'whats_new_14.xml#03-05',
'whats_new_14.xml#03-02',
'whats_new_14.xml#03-01',
'whats_new_14.xml#02-28',
'whats_new_14.xml#02-27',
'whats_new_14.xml#02-26',
'whats_new_14.xml#02-23',
'whats_new_14.xml#02-22',
'whats_new_14.xml#02-17',
'whats_new_14.xml#02-15',
'whats_new_14.xml#01-26',
'whats_new_14.xml#01-21',
'whats_new_14.xml#01-10'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
